@@ -1,6 +1,6 @@
 =head1 NAME
 
-Rubyish::String - String object acts as ruby
+Rubyish::String - String (class)
 
 =cut
 
@@ -9,10 +9,17 @@ package Rubyish::String;
 use base 'Rubyish::Object';
 use Rubyish::Syntax::def;
 
+use overload
+(
+  "+" => \&op_add,
+  "eq" => \&op_eq,
+  '""' => \&op_stringify
+);
+
 =head2 new($scalar) #=> string object
 
 constructor
-    
+
     $string = Rubyish::String->new;             #=> bless( do{\(my $o = '')}, 'Rubyish::String' )
     $string = Rubyish::String->new("hello");    #=> bless( do{\(my $o = 'hello')}, 'Rubyish::String' )
     $string = String("hello");                  # do the same
@@ -29,7 +36,7 @@ sub new {
 =head2 replace($scalar) #=> $instance
 
 replace content
-    
+
     $string = Rubyish::String->new("hello");    #=> bless( do{\(my $o = 'hello')}, 'Rubyish::String' )
     $string->replace("world")                   #=> bless( do{\(my $o = 'world')}, 'Rubyish::String' )
 
@@ -61,4 +68,27 @@ def gsub($pattern, $replacement) {
     return $str;
 };
 
+=head2 +
+
+=cut
+
+sub op_add {
+  my ($self, $other) = @_;
+  return ref($self)->new(${$self}.${$other});
+}
+
+sub op_eq {
+  my ($self, $other) = @_;
+  if (${$self} eq ${$other}) {
+    return 1;
+  } else {
+    undef;
+  }
+}
+
+sub op_stringify {
+    my $self = shift;
+    return $$self;
+}
+
 1;
